@@ -77,51 +77,99 @@ if ($_SERVER['REQUEST_METHOD'] === 'POST') {
                 }
                 break;
             case 'block_ip':
-                if (!empty($_POST['ip_address']) && filter_var($_POST['ip_address'], FILTER_VALIDATE_IP)) {
+                $ip_input = trim($_POST['ip_address'] ?? '');
+
+                // Validate IP or CIDR notation
+                $is_valid = false;
+                if (filter_var($ip_input, FILTER_VALIDATE_IP)) {
+                    $is_valid = true;
+                } elseif (strpos($ip_input, '/') !== false) {
+                    // Validate CIDR notation
+                    list($ip, $mask) = explode('/', $ip_input, 2);
+                    if (filter_var($ip, FILTER_VALIDATE_IP, FILTER_FLAG_IPV4) &&
+                        is_numeric($mask) && $mask >= 0 && $mask <= 32) {
+                        $is_valid = true;
+                    }
+                }
+
+                if ($is_valid && !empty($ip_input)) {
                     $reason = !empty($_POST['reason']) ? substr(trim($_POST['reason']), 0, 255) : 'Manual block';
                     $permanent = isset($_POST['permanent']) && $_POST['permanent'] == '1';
-                    $result = $SecManager->block_ip($_POST['ip_address'], $reason, 0, $permanent, false);
+                    $result = $SecManager->block_ip($ip_input, $reason, 0, $permanent, false);
                     if ($result) {
                         $block_type = $permanent ? 'permanently' : 'temporarily';
-                        $message = 'IP address blocked ' . $block_type . ': ' . htmlspecialchars($_POST['ip_address']);
+                        $entry_type = strpos($ip_input, '/') !== false ? 'CIDR range' : 'IP address';
+                        $message = $entry_type . ' blocked ' . $block_type . ': ' . htmlspecialchars($ip_input);
                         $message_type = 'success';
                     } else {
-                        $message = 'Error blocking IP address (may be exempted)';
+                        $message = 'Error blocking IP/CIDR (may be exempted or invalid)';
                         $message_type = 'danger';
                     }
                 } else {
-                    $message = 'Invalid IP address format';
+                    $message = 'Invalid IP address or CIDR notation format';
                     $message_type = 'danger';
                 }
                 break;
             case 'add_exemption':
-                if (!empty($_POST['ip_address']) && filter_var($_POST['ip_address'], FILTER_VALIDATE_IP)) {
+                $ip_input = trim($_POST['ip_address'] ?? '');
+
+                // Validate IP or CIDR notation
+                $is_valid = false;
+                if (filter_var($ip_input, FILTER_VALIDATE_IP)) {
+                    $is_valid = true;
+                } elseif (strpos($ip_input, '/') !== false) {
+                    // Validate CIDR notation
+                    list($ip, $mask) = explode('/', $ip_input, 2);
+                    if (filter_var($ip, FILTER_VALIDATE_IP, FILTER_FLAG_IPV4) &&
+                        is_numeric($mask) && $mask >= 0 && $mask <= 32) {
+                        $is_valid = true;
+                    }
+                }
+
+                if ($is_valid && !empty($ip_input)) {
                     $description = !empty($_POST['description']) ? substr(trim($_POST['description']), 0, 255) : '';
-                    $result = $SecManager->add_exemption_ip($_POST['ip_address'], $description);
+                    $result = $SecManager->add_exemption_ip($ip_input, $description);
                     if ($result) {
-                        $message = 'IP address added to exemption list: ' . htmlspecialchars($_POST['ip_address']);
+                        $entry_type = strpos($ip_input, '/') !== false ? 'CIDR range' : 'IP address';
+                        $message = $entry_type . ' added to exemption list: ' . htmlspecialchars($ip_input);
                         $message_type = 'success';
                     } else {
-                        $message = 'Error adding IP to exemption list';
+                        $message = 'Error adding IP/CIDR to exemption list';
                         $message_type = 'danger';
                     }
                 } else {
-                    $message = 'Invalid IP address format';
+                    $message = 'Invalid IP address or CIDR notation format';
                     $message_type = 'danger';
                 }
                 break;
             case 'remove_exemption':
-                if (!empty($_POST['ip_address']) && filter_var($_POST['ip_address'], FILTER_VALIDATE_IP)) {
-                    $result = $SecManager->remove_exemption_ip($_POST['ip_address']);
+                $ip_input = trim($_POST['ip_address'] ?? '');
+
+                // Validate IP or CIDR notation (same as add_exemption)
+                $is_valid = false;
+                if (filter_var($ip_input, FILTER_VALIDATE_IP)) {
+                    $is_valid = true;
+                } elseif (strpos($ip_input, '/') !== false) {
+                    // Validate CIDR notation
+                    list($ip, $mask) = explode('/', $ip_input, 2);
+                    if (filter_var($ip, FILTER_VALIDATE_IP, FILTER_FLAG_IPV4) &&
+                        is_numeric($mask) && $mask >= 0 && $mask <= 32) {
+                        $is_valid = true;
+                    }
+                }
+
+                if ($is_valid && !empty($ip_input)) {
+                    $result = $SecManager->remove_exemption_ip($ip_input);
                     if ($result) {
-                        $message = 'IP address removed from exemption list: ' . htmlspecialchars($_POST['ip_address']);
+                        $entry_type = strpos($ip_input, '/') !== false ? 'CIDR range' : 'IP address';
+                        $message = $entry_type . ' removed from exemption list: ' . htmlspecialchars($ip_input);
                         $message_type = 'success';
                     } else {
-                        $message = 'Error removing IP from exemption list';
+                        $message = 'Error removing IP/CIDR from exemption list';
                         $message_type = 'danger';
                     }
                 } else {
-                    $message = 'Invalid IP address format';
+                    $message = 'Invalid IP address or CIDR notation format';
                     $message_type = 'danger';
                 }
                 break;
@@ -584,15 +632,25 @@ $access_stats = $PermManager->get_system_access_stats(30);
     <div class="col-md-4">
         <div class="card h-100">
             <div class="card-header">
-                <h5 class="card-title mb-0">Block IP Address</h5>
+                <h5 class="card-title mb-0">
+                    <i class="fa fa-ban me-2"></i> Block IP Address or CIDR Range
+                </h5>
             </div>
             <div class="card-body">
                 <form method="POST" action="">
                     <input type="hidden" name="csrf_token" value="<?php echo get_csrf_token(); ?>">
                     <input type="hidden" name="action" value="block_ip">
                     <div class="mb-3">
-                        <label for="block_ip" class="form-label">IP Address</label>
-                        <input type="text" class="form-control" id="block_ip" name="ip_address" placeholder="192.168.1.100" required>
+                        <label for="block_ip" class="form-label">IP Address or CIDR</label>
+                        <input type="text" class="form-control" id="block_ip" name="ip_address"
+                               placeholder="192.168.1.100 or 192.168.1.0/24"
+                               pattern="^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)(?:\/(?:3[0-2]|[12]?[0-9]))?$"
+                               title="Enter a valid IP address (e.g., 192.168.1.100) or CIDR range (e.g., 192.168.1.0/24)"
+                               aria-describedby="block_ip_help"
+                               required>
+                        <small id="block_ip_help" class="form-text text-muted">
+                            Single IP or CIDR notation. Common masks: /32 (single IP), /24 (256 IPs), /16 (65,536 IPs)
+                        </small>
                     </div>
                     <div class="mb-3">
                         <label for="block_reason" class="form-label">Reason (optional)</label>
@@ -606,7 +664,7 @@ $access_stats = $PermManager->get_system_access_stats(30);
                             </label>
                         </div>
                     </div>
-                    <button type="submit" class="btn btn-danger">Block IP</button>
+                    <button type="submit" class="btn btn-danger">Block IP/CIDR</button>
                 </form>
             </div>
         </div>
@@ -615,17 +673,27 @@ $access_stats = $PermManager->get_system_access_stats(30);
     <div class="col-md-4">
         <div class="card h-100">
             <div class="card-header">
-                <h5 class="card-title mb-0">Unblock IP Address</h5>
+                <h5 class="card-title mb-0">
+                    <i class="fa fa-unlock me-2"></i> Unblock IP Address or CIDR Range
+                </h5>
             </div>
             <div class="card-body">
                 <form method="POST" action="">
                     <input type="hidden" name="csrf_token" value="<?php echo get_csrf_token(); ?>">
                     <input type="hidden" name="action" value="unblock_ip">
                     <div class="mb-3">
-                        <label for="unblock_ip" class="form-label">IP Address</label>
-                        <input type="text" class="form-control" id="unblock_ip" name="ip_address" placeholder="192.168.1.100" required>
+                        <label for="unblock_ip" class="form-label">IP Address or CIDR</label>
+                        <input type="text" class="form-control" id="unblock_ip" name="ip_address"
+                               placeholder="192.168.1.100 or 192.168.1.0/24"
+                               pattern="^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)(?:\/(?:3[0-2]|[12]?[0-9]))?$"
+                               title="Enter a valid IP address (e.g., 192.168.1.100) or CIDR range (e.g., 192.168.1.0/24)"
+                               aria-describedby="unblock_ip_help"
+                               required>
+                        <small id="unblock_ip_help" class="form-text text-muted">
+                            Single IP or CIDR notation. Common masks: /32 (single IP), /24 (256 IPs), /16 (65,536 IPs)
+                        </small>
                     </div>
-                    <button type="submit" class="btn btn-warning">Unblock IP</button>
+                    <button type="submit" class="btn btn-warning">Unblock IP/CIDR</button>
                 </form>
             </div>
         </div>
@@ -634,15 +702,25 @@ $access_stats = $PermManager->get_system_access_stats(30);
     <div class="col-md-4">
         <div class="card h-100">
             <div class="card-header">
-                <h5 class="card-title mb-0">Add Exemption</h5>
+                <h5 class="card-title mb-0">
+                    <i class="fa fa-check-circle me-2"></i> Add Exemption
+                </h5>
             </div>
             <div class="card-body">
                 <form method="POST" action="">
                     <input type="hidden" name="csrf_token" value="<?php echo get_csrf_token(); ?>">
                     <input type="hidden" name="action" value="add_exemption">
                     <div class="mb-3">
-                        <label for="exemption_ip" class="form-label">IP Address</label>
-                        <input type="text" class="form-control" id="exemption_ip" name="ip_address" placeholder="192.168.1.100" required>
+                        <label for="exemption_ip" class="form-label">IP Address or CIDR</label>
+                        <input type="text" class="form-control" id="exemption_ip" name="ip_address"
+                               placeholder="192.168.1.100 or 192.168.1.0/24"
+                               pattern="^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)(?:\/(?:3[0-2]|[12]?[0-9]))?$"
+                               title="Enter a valid IP address (e.g., 192.168.1.100) or CIDR range (e.g., 192.168.1.0/24)"
+                               aria-describedby="exemption_ip_help"
+                               required>
+                        <small id="exemption_ip_help" class="form-text text-muted">
+                            Exempt from all blocking (IP or CIDR). Common: /32 (single), /24 (local network), /8 (private range)
+                        </small>
                     </div>
                     <div class="mb-3">
                         <label for="exemption_description" class="form-label">Description (optional)</label>
@@ -659,13 +737,13 @@ $access_stats = $PermManager->get_system_access_stats(30);
     <div class="col-md-12">
         <div class="card">
             <div class="card-header">
-                <h5 class="card-title mb-0">Exempt IPs</h5>
+                <h5 class="card-title mb-0">Exempt IPs and CIDR Ranges</h5>
             </div>
             <div class="card-body">
                 <div class="table-responsive">
                     <table class="table table-striped table-hover">
                         <thead class="table-dark">
-                            <tr><th>IP Address</th><th>Description</th><th width="120">Action</th></tr>
+                            <tr><th>IP Address / CIDR</th><th>Description</th><th width="120">Action</th></tr>
                         </thead>
                         <tbody>
                             <?php if (empty($exemption_ips)): ?>
@@ -839,7 +917,12 @@ if (!empty($service_blocked_ips)): ?>
                                     ?>
                                     <span class="badge bg-<?php echo $badge_class; ?>"><?php echo $service_display; ?></span>
                                 </td>
-                                <td><code><?php echo htmlspecialchars($blocked['ip_address']); ?></code></td>
+                                <td>
+                                    <code><?php echo htmlspecialchars($blocked['ip_address']); ?></code>
+                                    <?php if (strpos($blocked['ip_address'], '/') !== false): ?>
+                                        <span class="badge bg-info ms-1" title="CIDR Range">RANGE</span>
+                                    <?php endif; ?>
+                                </td>
                                 <td>
                                     <small title="<?php echo date('Y-m-d H:i:s', $blocked['block_time']); ?>">
                                         <?php 
@@ -1022,4 +1105,26 @@ if (!empty($service_blocked_ips)): ?>
             </div>
         </div>
     </div>
-</div> 
\ No newline at end of file
+</div>
+
+<script>
+// Real-time CIDR/IP validation for all IP input fields
+document.addEventListener('DOMContentLoaded', function() {
+    const ipInputs = document.querySelectorAll('#block_ip, #unblock_ip, #exemption_ip');
+    const ipv4Pattern = /^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)(?:\/(?:3[0-2]|[12]?[0-9]))?$/;
+
+    ipInputs.forEach(input => {
+        input.addEventListener('input', function() {
+            if (this.value.trim() === '') {
+                this.classList.remove('is-valid', 'is-invalid');
+            } else if (ipv4Pattern.test(this.value.trim())) {
+                this.classList.remove('is-invalid');
+                this.classList.add('is-valid');
+            } else {
+                this.classList.remove('is-valid');
+                this.classList.add('is-invalid');
+            }
+        });
+    });
+});
+</script>
\ No newline at end of file
